# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GeomProjLib module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geomprojlib.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GeomProjLib
else:
    import _GeomProjLib

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GeomProjLib.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GeomProjLib.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GeomProjLib.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GeomProjLib.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GeomProjLib.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GeomProjLib.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomProjLib.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomProjLib.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomProjLib.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GeomProjLib.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GeomProjLib:
_GeomProjLib.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GeomProjLib.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *



class geomprojlib(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Curve2d(*args) -> "Standard_Real &":
        r"""
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        First: float
        Last: float
        S: Geom_Surface
        UFirst: float
        ULast: float
        VFirst: float
        VLast: float

        Returns
        -------
        Tolerance: float
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        First: float
        Last: float
        S: Geom_Surface

        Returns
        -------
        Tolerance: float
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        First: float
        Last: float
        S: Geom_Surface

        Returns
        -------
        opencascade::handle<Geom2d_Curve>
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface

        Returns
        -------
        opencascade::handle<Geom2d_Curve>
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface
        UDeb: float
        UFin: float
        VDeb: float
        VFin: float

        Returns
        -------
        opencascade::handle<Geom2d_Curve>
        Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface
        UDeb: float
        UFin: float
        VDeb: float
        VFin: float

        Returns
        -------
        Tolerance: float

        """
        return _GeomProjLib.geomprojlib_Curve2d(*args)

    @staticmethod
    def Project(*args) -> "opencascade::handle< Geom_Curve >":
        r"""
        Constructs the 3d-curve from the normal projection of the curve <c> on the surface <s>. warning : if the projection has failes returns a null handle.

        Parameters
        ----------
        C: Geom_Curve
        S: Geom_Surface

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _GeomProjLib.geomprojlib_Project(*args)

    @staticmethod
    def ProjectOnPlane(*args) -> "opencascade::handle< Geom_Curve >":
        r"""
        Constructs the 3d-curves from the projection of the curve <curve> on the plane <plane> along the direction <dir>. if <keepparametrization> is true, the parametrization of the projected curve <pc> will be the same as the parametrization of the initial curve <c>. it meens: proj(c(u)) = pc(u) for each u. otherwize, the parametrization may change.

        Parameters
        ----------
        Curve: Geom_Curve
        Plane: Geom_Plane
        Dir: gp_Dir
        KeepParametrization: bool

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _GeomProjLib.geomprojlib_ProjectOnPlane(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _GeomProjLib.geomprojlib_swiginit(self, _GeomProjLib.new_geomprojlib())
    __swig_destroy__ = _GeomProjLib.delete_geomprojlib

# Register geomprojlib in _GeomProjLib:
_GeomProjLib.geomprojlib_swigregister(geomprojlib)

def geomprojlib_Curve2d(*args) -> "Standard_Real &":
    r"""
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    First: float
    Last: float
    S: Geom_Surface
    UFirst: float
    ULast: float
    VFirst: float
    VLast: float

    Returns
    -------
    Tolerance: float
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] <tolerance> is used as input if the projection needs an approximation. in this case, the reached tolerance is set in <tolerance> as output. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    First: float
    Last: float
    S: Geom_Surface

    Returns
    -------
    Tolerance: float
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ) the 3dcurve is taken between the parametrization range [first, last] if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    First: float
    Last: float
    S: Geom_Surface

    Returns
    -------
    opencascade::handle<Geom2d_Curve>
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface

    Returns
    -------
    opencascade::handle<Geom2d_Curve>
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface
    UDeb: float
    UFin: float
    VDeb: float
    VFin: float

    Returns
    -------
    opencascade::handle<Geom2d_Curve>
    Gives the 2d-curve of a 3d-curve lying on a surface ( uses geomprojlib_projectedcurve ). if the projection needs an approximation, precision::papproximation() is used. warning : if the projection has failed, this method returns a null handle. can expand a little the bounds of surface.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface
    UDeb: float
    UFin: float
    VDeb: float
    VFin: float

    Returns
    -------
    Tolerance: float

    """
    return _GeomProjLib.geomprojlib_Curve2d(*args)

def geomprojlib_Project(*args) -> "opencascade::handle< Geom_Curve >":
    r"""
    Constructs the 3d-curve from the normal projection of the curve <c> on the surface <s>. warning : if the projection has failes returns a null handle.

    Parameters
    ----------
    C: Geom_Curve
    S: Geom_Surface

    Returns
    -------
    opencascade::handle<Geom_Curve>

    """
    return _GeomProjLib.geomprojlib_Project(*args)

def geomprojlib_ProjectOnPlane(*args) -> "opencascade::handle< Geom_Curve >":
    r"""
    Constructs the 3d-curves from the projection of the curve <curve> on the plane <plane> along the direction <dir>. if <keepparametrization> is true, the parametrization of the projected curve <pc> will be the same as the parametrization of the initial curve <c>. it meens: proj(c(u)) = pc(u) for each u. otherwize, the parametrization may change.

    Parameters
    ----------
    Curve: Geom_Curve
    Plane: Geom_Plane
    Dir: gp_Dir
    KeepParametrization: bool

    Returns
    -------
    opencascade::handle<Geom_Curve>

    """
    return _GeomProjLib.geomprojlib_ProjectOnPlane(*args)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopAbs import *


class TopBas_ListOfTestInterference:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TopBas_TestInterference: ...
    def Last(self) -> TopBas_TestInterference: ...
    def Append(self, theItem: TopBas_TestInterference) -> TopBas_TestInterference: ...
    def Prepend(self, theItem: TopBas_TestInterference) -> TopBas_TestInterference: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TopBas_TestInterference: ...
    def SetValue(self, theIndex: int, theValue: TopBas_TestInterference) -> None: ...

class TopBas_TestInterference:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Inters: float, Bound: int, Orient: TopAbs_Orientation, Trans: TopAbs_Orientation, BTrans: TopAbs_Orientation) -> None: ...
	@overload
	def Boundary(self, B: int) -> None: ...
	@overload
	def Boundary(self) -> int: ...
	@overload
	def BoundaryTransition(self, BTr: TopAbs_Orientation) -> None: ...
	@overload
	def BoundaryTransition(self) -> TopAbs_Orientation: ...
	def GetChangeBoundary(self) -> int: ...
	def SetChangeBoundary(self, value: int) -> None: ...
	def GetChangeIntersection(self) -> float: ...
	def SetChangeIntersection(self, value: float) -> None: ...
	@overload
	def Intersection(self, I: float) -> None: ...
	@overload
	def Intersection(self) -> float: ...
	@overload
	def Orientation(self, O: TopAbs_Orientation) -> None: ...
	@overload
	def Orientation(self) -> TopAbs_Orientation: ...
	@overload
	def Transition(self, Tr: TopAbs_Orientation) -> None: ...
	@overload
	def Transition(self) -> TopAbs_Orientation: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GeomToStep module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geomtostep.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GeomToStep
else:
    import _GeomToStep

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GeomToStep.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GeomToStep.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomToStep.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomToStep.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GeomToStep.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GeomToStep.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GeomToStep.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GeomToStep.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GeomToStep.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GeomToStep.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomToStep.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GeomToStep.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GeomToStep.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomToStep.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomToStep.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomToStep.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GeomToStep.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GeomToStep:
_GeomToStep.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GeomToStep.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d
import OCC.Core.StepGeom
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.Resource
import OCC.Core.StepRepr
import OCC.Core.StepBasic

from enum import IntEnum
from OCC.Core.Exception import *



class GeomToStep_Root(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _GeomToStep.GeomToStep_Root_IsDone(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _GeomToStep.GeomToStep_Root_swiginit(self, _GeomToStep.new_GeomToStep_Root())
    __swig_destroy__ = _GeomToStep.delete_GeomToStep_Root

# Register GeomToStep_Root in _GeomToStep:
_GeomToStep.GeomToStep_Root_swigregister(GeomToStep_Root)

class GeomToStep_MakeAxis1Placement(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        A: gp_Ax1

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        A: gp_Ax2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        A: Geom_Axis1Placement

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        A: Geom2d_AxisPlacement

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeAxis1Placement_swiginit(self, _GeomToStep.new_GeomToStep_MakeAxis1Placement(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Axis1Placement > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Axis1Placement>

        """
        return _GeomToStep.GeomToStep_MakeAxis1Placement_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeAxis1Placement

# Register GeomToStep_MakeAxis1Placement in _GeomToStep:
_GeomToStep.GeomToStep_MakeAxis1Placement_swigregister(GeomToStep_MakeAxis1Placement)

class GeomToStep_MakeAxis2Placement2d(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        A: gp_Ax2

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        A: gp_Ax22d

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeAxis2Placement2d_swiginit(self, _GeomToStep.new_GeomToStep_MakeAxis2Placement2d(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Axis2Placement2d > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Axis2Placement2d>

        """
        return _GeomToStep.GeomToStep_MakeAxis2Placement2d_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeAxis2Placement2d

# Register GeomToStep_MakeAxis2Placement2d in _GeomToStep:
_GeomToStep.GeomToStep_MakeAxis2Placement2d_swigregister(GeomToStep_MakeAxis2Placement2d)

class GeomToStep_MakeAxis2Placement3d(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        A: gp_Ax2

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        A: gp_Ax3

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        T: gp_Trsf

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        A: Geom_Axis2Placement

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeAxis2Placement3d_swiginit(self, _GeomToStep.new_GeomToStep_MakeAxis2Placement3d(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Axis2Placement3d > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Axis2Placement3d>

        """
        return _GeomToStep.GeomToStep_MakeAxis2Placement3d_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeAxis2Placement3d

# Register GeomToStep_MakeAxis2Placement3d in _GeomToStep:
_GeomToStep.GeomToStep_MakeAxis2Placement3d_swigregister(GeomToStep_MakeAxis2Placement3d)

class GeomToStep_MakeBSplineCurveWithKnots(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Bsplin: Geom_BSplineCurve

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Bsplin: Geom2d_BSplineCurve

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeBSplineCurveWithKnots_swiginit(self, _GeomToStep.new_GeomToStep_MakeBSplineCurveWithKnots(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_BSplineCurveWithKnots > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_BSplineCurveWithKnots>

        """
        return _GeomToStep.GeomToStep_MakeBSplineCurveWithKnots_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeBSplineCurveWithKnots

# Register GeomToStep_MakeBSplineCurveWithKnots in _GeomToStep:
_GeomToStep.GeomToStep_MakeBSplineCurveWithKnots_swigregister(GeomToStep_MakeBSplineCurveWithKnots)

class GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Bsplin: Geom_BSplineCurve

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Bsplin: Geom2d_BSplineCurve

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve_swiginit(self, _GeomToStep.new_GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve>

        """
        return _GeomToStep.GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve

# Register GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve in _GeomToStep:
_GeomToStep.GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve_swigregister(GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve)

class GeomToStep_MakeBSplineSurfaceWithKnots(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Bsplin: Geom_BSplineSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeBSplineSurfaceWithKnots_swiginit(self, _GeomToStep.new_GeomToStep_MakeBSplineSurfaceWithKnots(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_BSplineSurfaceWithKnots > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_BSplineSurfaceWithKnots>

        """
        return _GeomToStep.GeomToStep_MakeBSplineSurfaceWithKnots_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeBSplineSurfaceWithKnots

# Register GeomToStep_MakeBSplineSurfaceWithKnots in _GeomToStep:
_GeomToStep.GeomToStep_MakeBSplineSurfaceWithKnots_swigregister(GeomToStep_MakeBSplineSurfaceWithKnots)

class GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Bsplin: Geom_BSplineSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface>

        """
        return _GeomToStep.GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface

# Register GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface_swigregister(GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface)

class GeomToStep_MakeBoundedCurve(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_BoundedCurve

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom2d_BoundedCurve

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeBoundedCurve_swiginit(self, _GeomToStep.new_GeomToStep_MakeBoundedCurve(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_BoundedCurve > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_BoundedCurve>

        """
        return _GeomToStep.GeomToStep_MakeBoundedCurve_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeBoundedCurve

# Register GeomToStep_MakeBoundedCurve in _GeomToStep:
_GeomToStep.GeomToStep_MakeBoundedCurve_swigregister(GeomToStep_MakeBoundedCurve)

class GeomToStep_MakeBoundedSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_BoundedSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeBoundedSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeBoundedSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_BoundedSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_BoundedSurface>

        """
        return _GeomToStep.GeomToStep_MakeBoundedSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeBoundedSurface

# Register GeomToStep_MakeBoundedSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeBoundedSurface_swigregister(GeomToStep_MakeBoundedSurface)

class GeomToStep_MakeCartesianPoint(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: Geom_CartesianPoint

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: Geom2d_CartesianPoint

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeCartesianPoint_swiginit(self, _GeomToStep.new_GeomToStep_MakeCartesianPoint(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_CartesianPoint > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_CartesianPoint>

        """
        return _GeomToStep.GeomToStep_MakeCartesianPoint_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeCartesianPoint

# Register GeomToStep_MakeCartesianPoint in _GeomToStep:
_GeomToStep.GeomToStep_MakeCartesianPoint_swigregister(GeomToStep_MakeCartesianPoint)

class GeomToStep_MakeCircle(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: gp_Circ

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom_Circle

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Circle

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeCircle_swiginit(self, _GeomToStep.new_GeomToStep_MakeCircle(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Circle > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Circle>

        """
        return _GeomToStep.GeomToStep_MakeCircle_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeCircle

# Register GeomToStep_MakeCircle in _GeomToStep:
_GeomToStep.GeomToStep_MakeCircle_swigregister(GeomToStep_MakeCircle)

class GeomToStep_MakeConic(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_Conic

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Conic

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeConic_swiginit(self, _GeomToStep.new_GeomToStep_MakeConic(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Conic > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Conic>

        """
        return _GeomToStep.GeomToStep_MakeConic_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeConic

# Register GeomToStep_MakeConic in _GeomToStep:
_GeomToStep.GeomToStep_MakeConic_swigregister(GeomToStep_MakeConic)

class GeomToStep_MakeConicalSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        CSurf: Geom_ConicalSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeConicalSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeConicalSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_ConicalSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_ConicalSurface>

        """
        return _GeomToStep.GeomToStep_MakeConicalSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeConicalSurface

# Register GeomToStep_MakeConicalSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeConicalSurface_swigregister(GeomToStep_MakeConicalSurface)

class GeomToStep_MakeCurve(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_Curve

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeCurve_swiginit(self, _GeomToStep.new_GeomToStep_MakeCurve(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Curve > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Curve>

        """
        return _GeomToStep.GeomToStep_MakeCurve_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeCurve

# Register GeomToStep_MakeCurve in _GeomToStep:
_GeomToStep.GeomToStep_MakeCurve_swigregister(GeomToStep_MakeCurve)

class GeomToStep_MakeCylindricalSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        CSurf: Geom_CylindricalSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeCylindricalSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeCylindricalSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_CylindricalSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_CylindricalSurface>

        """
        return _GeomToStep.GeomToStep_MakeCylindricalSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeCylindricalSurface

# Register GeomToStep_MakeCylindricalSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeCylindricalSurface_swigregister(GeomToStep_MakeCylindricalSurface)

class GeomToStep_MakeDirection(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        D: gp_Dir

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        D: gp_Dir2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        D: Geom_Direction

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        D: Geom2d_Direction

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeDirection_swiginit(self, _GeomToStep.new_GeomToStep_MakeDirection(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Direction > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Direction>

        """
        return _GeomToStep.GeomToStep_MakeDirection_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeDirection

# Register GeomToStep_MakeDirection in _GeomToStep:
_GeomToStep.GeomToStep_MakeDirection_swigregister(GeomToStep_MakeDirection)

class GeomToStep_MakeElementarySurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: Geom_ElementarySurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeElementarySurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeElementarySurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_ElementarySurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_ElementarySurface>

        """
        return _GeomToStep.GeomToStep_MakeElementarySurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeElementarySurface

# Register GeomToStep_MakeElementarySurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeElementarySurface_swigregister(GeomToStep_MakeElementarySurface)

class GeomToStep_MakeEllipse(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: gp_Elips

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom_Ellipse

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Ellipse

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeEllipse_swiginit(self, _GeomToStep.new_GeomToStep_MakeEllipse(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Ellipse > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Ellipse>

        """
        return _GeomToStep.GeomToStep_MakeEllipse_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeEllipse

# Register GeomToStep_MakeEllipse in _GeomToStep:
_GeomToStep.GeomToStep_MakeEllipse_swigregister(GeomToStep_MakeEllipse)

class GeomToStep_MakeHyperbola(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Hyperbola

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom_Hyperbola

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeHyperbola_swiginit(self, _GeomToStep.new_GeomToStep_MakeHyperbola(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Hyperbola > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Hyperbola>

        """
        return _GeomToStep.GeomToStep_MakeHyperbola_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeHyperbola

# Register GeomToStep_MakeHyperbola in _GeomToStep:
_GeomToStep.GeomToStep_MakeHyperbola_swigregister(GeomToStep_MakeHyperbola)

class GeomToStep_MakeLine(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        L: gp_Lin

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        L: gp_Lin2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom_Line

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Line

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeLine_swiginit(self, _GeomToStep.new_GeomToStep_MakeLine(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Line > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Line>

        """
        return _GeomToStep.GeomToStep_MakeLine_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeLine

# Register GeomToStep_MakeLine in _GeomToStep:
_GeomToStep.GeomToStep_MakeLine_swigregister(GeomToStep_MakeLine)

class GeomToStep_MakeParabola(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Parabola

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom_Parabola

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeParabola_swiginit(self, _GeomToStep.new_GeomToStep_MakeParabola(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Parabola > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Parabola>

        """
        return _GeomToStep.GeomToStep_MakeParabola_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeParabola

# Register GeomToStep_MakeParabola in _GeomToStep:
_GeomToStep.GeomToStep_MakeParabola_swigregister(GeomToStep_MakeParabola)

class GeomToStep_MakePlane(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pln

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: Geom_Plane

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakePlane_swiginit(self, _GeomToStep.new_GeomToStep_MakePlane(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Plane > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Plane>

        """
        return _GeomToStep.GeomToStep_MakePlane_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakePlane

# Register GeomToStep_MakePlane in _GeomToStep:
_GeomToStep.GeomToStep_MakePlane_swigregister(GeomToStep_MakePlane)

class GeomToStep_MakePolyline(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        P: TColgp_Array1OfPnt

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: TColgp_Array1OfPnt2d

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakePolyline_swiginit(self, _GeomToStep.new_GeomToStep_MakePolyline(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Polyline > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Polyline>

        """
        return _GeomToStep.GeomToStep_MakePolyline_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakePolyline

# Register GeomToStep_MakePolyline in _GeomToStep:
_GeomToStep.GeomToStep_MakePolyline_swigregister(GeomToStep_MakePolyline)

class GeomToStep_MakeRectangularTrimmedSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        RTSurf: Geom_RectangularTrimmedSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeRectangularTrimmedSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeRectangularTrimmedSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_RectangularTrimmedSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_RectangularTrimmedSurface>

        """
        return _GeomToStep.GeomToStep_MakeRectangularTrimmedSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeRectangularTrimmedSurface

# Register GeomToStep_MakeRectangularTrimmedSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeRectangularTrimmedSurface_swigregister(GeomToStep_MakeRectangularTrimmedSurface)

class GeomToStep_MakeSphericalSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        CSurf: Geom_SphericalSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeSphericalSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeSphericalSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_SphericalSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_SphericalSurface>

        """
        return _GeomToStep.GeomToStep_MakeSphericalSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeSphericalSurface

# Register GeomToStep_MakeSphericalSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeSphericalSurface_swigregister(GeomToStep_MakeSphericalSurface)

class GeomToStep_MakeSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_Surface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Surface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Surface>

        """
        return _GeomToStep.GeomToStep_MakeSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeSurface

# Register GeomToStep_MakeSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeSurface_swigregister(GeomToStep_MakeSurface)

class GeomToStep_MakeSurfaceOfLinearExtrusion(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        CSurf: Geom_SurfaceOfLinearExtrusion

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeSurfaceOfLinearExtrusion_swiginit(self, _GeomToStep.new_GeomToStep_MakeSurfaceOfLinearExtrusion(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_SurfaceOfLinearExtrusion > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_SurfaceOfLinearExtrusion>

        """
        return _GeomToStep.GeomToStep_MakeSurfaceOfLinearExtrusion_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeSurfaceOfLinearExtrusion

# Register GeomToStep_MakeSurfaceOfLinearExtrusion in _GeomToStep:
_GeomToStep.GeomToStep_MakeSurfaceOfLinearExtrusion_swigregister(GeomToStep_MakeSurfaceOfLinearExtrusion)

class GeomToStep_MakeSurfaceOfRevolution(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        RevSurf: Geom_SurfaceOfRevolution

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeSurfaceOfRevolution_swiginit(self, _GeomToStep.new_GeomToStep_MakeSurfaceOfRevolution(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_SurfaceOfRevolution > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_SurfaceOfRevolution>

        """
        return _GeomToStep.GeomToStep_MakeSurfaceOfRevolution_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeSurfaceOfRevolution

# Register GeomToStep_MakeSurfaceOfRevolution in _GeomToStep:
_GeomToStep.GeomToStep_MakeSurfaceOfRevolution_swigregister(GeomToStep_MakeSurfaceOfRevolution)

class GeomToStep_MakeSweptSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: Geom_SweptSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeSweptSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeSweptSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_SweptSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_SweptSurface>

        """
        return _GeomToStep.GeomToStep_MakeSweptSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeSweptSurface

# Register GeomToStep_MakeSweptSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeSweptSurface_swigregister(GeomToStep_MakeSweptSurface)

class GeomToStep_MakeToroidalSurface(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        TorSurf: Geom_ToroidalSurface

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeToroidalSurface_swiginit(self, _GeomToStep.new_GeomToStep_MakeToroidalSurface(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_ToroidalSurface > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_ToroidalSurface>

        """
        return _GeomToStep.GeomToStep_MakeToroidalSurface_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeToroidalSurface

# Register GeomToStep_MakeToroidalSurface in _GeomToStep:
_GeomToStep.GeomToStep_MakeToroidalSurface_swigregister(GeomToStep_MakeToroidalSurface)

class GeomToStep_MakeVector(GeomToStep_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        V: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        V: gp_Vec2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        V: Geom_Vector

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        V: Geom2d_Vector

        Returns
        -------
        None

        """
        _GeomToStep.GeomToStep_MakeVector_swiginit(self, _GeomToStep.new_GeomToStep_MakeVector(*args))

    def Value(self, *args) -> "opencascade::handle< StepGeom_Vector > const &":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepGeom_Vector>

        """
        return _GeomToStep.GeomToStep_MakeVector_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GeomToStep.delete_GeomToStep_MakeVector

# Register GeomToStep_MakeVector in _GeomToStep:
_GeomToStep.GeomToStep_MakeVector_swigregister(GeomToStep_MakeVector)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GCE2d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_gce2d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GCE2d
else:
    import _GCE2d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GCE2d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GCE2d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GCE2d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GCE2d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GCE2d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GCE2d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GCE2d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GCE2d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GCE2d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GCE2d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GCE2d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GCE2d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GCE2d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GCE2d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GCE2d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GCE2d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GCE2d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GCE2d:
_GCE2d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GCE2d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Geom2d
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.gce

from enum import IntEnum
from OCC.Core.Exception import *



class GCE2d_MakeMirror(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Point: gp_Pnt2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Axis: gp_Ax2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Line: gp_Lin2d

        Returns
        -------
        None
        Make a symetry transformation af axis defined by <point> and <direc>.

        Parameters
        ----------
        Point: gp_Pnt2d
        Direc: gp_Dir2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeMirror_swiginit(self, _GCE2d.new_GCE2d_MakeMirror(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Transformation > const &":
        r"""
        Returns the constructed transformation.

        Returns
        -------
        opencascade::handle<Geom2d_Transformation>

        """
        return _GCE2d.GCE2d_MakeMirror_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeMirror

# Register GCE2d_MakeMirror in _GCE2d:
_GCE2d.GCE2d_MakeMirror_swigregister(GCE2d_MakeMirror)

class GCE2d_MakeRotation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a rotation through angle angle about the center point.

        Parameters
        ----------
        Point: gp_Pnt2d
        Angle: float

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeRotation_swiginit(self, _GCE2d.new_GCE2d_MakeRotation(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Transformation > const &":
        r"""
        Returns the constructed transformation.

        Returns
        -------
        opencascade::handle<Geom2d_Transformation>

        """
        return _GCE2d.GCE2d_MakeRotation_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeRotation

# Register GCE2d_MakeRotation in _GCE2d:
_GCE2d.GCE2d_MakeRotation_swigregister(GCE2d_MakeRotation)

class GCE2d_MakeScale(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a scaling transformation with - point as the center of the transformation, and - scale as the scale factor.

        Parameters
        ----------
        Point: gp_Pnt2d
        Scale: float

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeScale_swiginit(self, _GCE2d.new_GCE2d_MakeScale(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Transformation > const &":
        r"""
        Returns the constructed transformation.

        Returns
        -------
        opencascade::handle<Geom2d_Transformation>

        """
        return _GCE2d.GCE2d_MakeScale_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeScale

# Register GCE2d_MakeScale in _GCE2d:
_GCE2d.GCE2d_MakeScale_swigregister(GCE2d_MakeScale)

class GCE2d_MakeTranslation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs a translation along the vector vect.

        Parameters
        ----------
        Vect: gp_Vec2d

        Returns
        -------
        None
        Constructs a translation along the vector (point1,point2) defined from the point point1 to the point point2.

        Parameters
        ----------
        Point1: gp_Pnt2d
        Point2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeTranslation_swiginit(self, _GCE2d.new_GCE2d_MakeTranslation(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Transformation > const &":
        r"""
        Returns the constructed transformation.

        Returns
        -------
        opencascade::handle<Geom2d_Transformation>

        """
        return _GCE2d.GCE2d_MakeTranslation_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeTranslation

# Register GCE2d_MakeTranslation in _GCE2d:
_GCE2d.GCE2d_MakeTranslation_swigregister(GCE2d_MakeTranslation)

class GCE2d_Root(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the construction is successful.

        Returns
        -------
        bool

        """
        return _GCE2d.GCE2d_Root_IsDone(self, *args)

    def Status(self, *args) -> "gce_ErrorType":
        r"""
        Returns the status of the construction - gce_done, if the construction is successful, or - another value of the gce_errortype enumeration indicating why the construction failed.

        Returns
        -------
        gce_ErrorType

        """
        return _GCE2d.GCE2d_Root_Status(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _GCE2d.GCE2d_Root_swiginit(self, _GCE2d.new_GCE2d_Root())
    __swig_destroy__ = _GCE2d.delete_GCE2d_Root

# Register GCE2d_Root in _GCE2d:
_GCE2d.GCE2d_Root_swigregister(GCE2d_Root)

class GCE2d_MakeArcOfCircle(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Makes an arc of circle (trimmedcurve from geom2d) from a circle between two parameters alpha1 and alpha2. the two parameters are angles. the parameters are in radians.

        Parameters
        ----------
        Circ: gp_Circ2d
        Alpha1: float
        Alpha2: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Makes an arc of circle (trimmedcurve from geom2d) from a circle between point <p> and the parameter alpha. alpha is given in radians.

        Parameters
        ----------
        Circ: gp_Circ2d
        P: gp_Pnt2d
        Alpha: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Makes an arc of circle (trimmedcurve from geom2d) from a circle between two points p1 and p2.

        Parameters
        ----------
        Circ: gp_Circ2d
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Makes an arc of circle (trimmedcurve from geom2d) from three points p1,p2,p3 between two points p1 and p3, and passing through the point p2.

        Parameters
        ----------
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        P3: gp_Pnt2d

        Returns
        -------
        None
        Makes an arc of circle (trimmedcurve from geom2d) from two points p1,p2 and the tangente to the solution at the point p1.

        Parameters
        ----------
        P1: gp_Pnt2d
        V: gp_Vec2d
        P2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeArcOfCircle_swiginit(self, _GCE2d.new_GCE2d_MakeArcOfCircle(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_TrimmedCurve > const &":
        r"""
        Returns the constructed arc of circle. exceptions stdfail_notdone if no arc of circle is constructed.

        Returns
        -------
        opencascade::handle<Geom2d_TrimmedCurve>

        """
        return _GCE2d.GCE2d_MakeArcOfCircle_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeArcOfCircle

# Register GCE2d_MakeArcOfCircle in _GCE2d:
_GCE2d.GCE2d_MakeArcOfCircle_swigregister(GCE2d_MakeArcOfCircle)

class GCE2d_MakeArcOfEllipse(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make an arc of ellipse (trimmedcurve from geom2d) from a ellipse between two parameters alpha1 and alpha2.

        Parameters
        ----------
        Elips: gp_Elips2d
        Alpha1: float
        Alpha2: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Make an arc of ellipse (trimmedcurve from geom2d) from a ellipse between point <p> and the parameter alpha.

        Parameters
        ----------
        Elips: gp_Elips2d
        P: gp_Pnt2d
        Alpha: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Make an arc of ellipse (trimmedcurve from geom2d) from a ellipse between two points p1 and p2. please, note: the orientation of the arc is: - the trigonometric sense if sense is not defined or is true (default value), or - the opposite sense if sense is false. - alpha1, alpha2 and alpha are angle values, given in radians. - isdone always returns true.

        Parameters
        ----------
        Elips: gp_Elips2d
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeArcOfEllipse_swiginit(self, _GCE2d.new_GCE2d_MakeArcOfEllipse(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_TrimmedCurve > const &":
        r"""
        Returns the constructed arc of ellipse.

        Returns
        -------
        opencascade::handle<Geom2d_TrimmedCurve>

        """
        return _GCE2d.GCE2d_MakeArcOfEllipse_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeArcOfEllipse

# Register GCE2d_MakeArcOfEllipse in _GCE2d:
_GCE2d.GCE2d_MakeArcOfEllipse_swigregister(GCE2d_MakeArcOfEllipse)

class GCE2d_MakeArcOfHyperbola(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Makes an arc of hyperbola (trimmedcurve from geom2d) from a hyperbola between two parameters alpha1 and alpha2.

        Parameters
        ----------
        Hypr: gp_Hypr2d
        Alpha1: float
        Alpha2: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Makes an arc of hyperbola (trimmedcurve from geom2d) from a hyperbola between point <p> and the parameter alpha.

        Parameters
        ----------
        Hypr: gp_Hypr2d
        P: gp_Pnt2d
        Alpha: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Makes an arc of hyperbola (trimmedcurve from geom2d) from a hyperbola between two points p1 and p2. note: the orientation of the arc of hyperbola is: - the trigonometric sense if sense is not defined or is true (default value), or - the opposite sense if sense is false. - isdone always returns true.

        Parameters
        ----------
        Hypr: gp_Hypr2d
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeArcOfHyperbola_swiginit(self, _GCE2d.new_GCE2d_MakeArcOfHyperbola(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_TrimmedCurve > const &":
        r"""
        Returns the constructed arc of hyperbola.

        Returns
        -------
        opencascade::handle<Geom2d_TrimmedCurve>

        """
        return _GCE2d.GCE2d_MakeArcOfHyperbola_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeArcOfHyperbola

# Register GCE2d_MakeArcOfHyperbola in _GCE2d:
_GCE2d.GCE2d_MakeArcOfHyperbola_swigregister(GCE2d_MakeArcOfHyperbola)

class GCE2d_MakeArcOfParabola(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make an arc of parabola (trimmedcurve from geom2d) from a parabola between two parameters alpha1 and alpha2.

        Parameters
        ----------
        Parab: gp_Parab2d
        Alpha1: float
        Alpha2: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Make an arc of parabola (trimmedcurve from geom2d) from a parabola between point <p> and the parameter alpha.

        Parameters
        ----------
        Parab: gp_Parab2d
        P: gp_Pnt2d
        Alpha: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Make an arc of parabola (trimmedcurve from geom2d) from a parabola between two points p1 and p2. please, note: the orientation of the arc of parabola is: - the trigonometric sense if sense is not defined or is true (default value), or - the opposite sense if sense is false. - isdone always returns true.

        Parameters
        ----------
        Parab: gp_Parab2d
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeArcOfParabola_swiginit(self, _GCE2d.new_GCE2d_MakeArcOfParabola(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_TrimmedCurve > const &":
        r"""
        Returns the constructed arc of parabola.

        Returns
        -------
        opencascade::handle<Geom2d_TrimmedCurve>

        """
        return _GCE2d.GCE2d_MakeArcOfParabola_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeArcOfParabola

# Register GCE2d_MakeArcOfParabola in _GCE2d:
_GCE2d.GCE2d_MakeArcOfParabola_swigregister(GCE2d_MakeArcOfParabola)

class GCE2d_MakeCircle(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a circle from a non persistent one.

        Parameters
        ----------
        C: gp_Circ2d

        Returns
        -------
        None
        A is the 'xaxis' of the circle which defines the origin of parametrization. it is not forbidden to create a circle with radius = 0.0 the status is 'negativeradius' if radius < 0.

        Parameters
        ----------
        A: gp_Ax2d
        Radius: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        A is the local coordinate system of the circle which defines the origin of parametrization. it is not forbidden to create a circle with radius = 0.0 the status is 'negativeradius' if radius < 0.

        Parameters
        ----------
        A: gp_Ax22d
        Radius: float

        Returns
        -------
        None
        Make a circle from geom2d <thecirc> parallel to another circ <circ> with a distance <dist>. if dist is greater than zero the result is enclosing the circle <circ>, else the result is enclosed by the circle <circ>.

        Parameters
        ----------
        Circ: gp_Circ2d
        Dist: float

        Returns
        -------
        None
        Make a circle from geom2d <thecirc> parallel to another circ <circ> and passing through a pnt <point>.

        Parameters
        ----------
        Circ: gp_Circ2d
        Point: gp_Pnt2d

        Returns
        -------
        None
        Make a circ from gp <thecirc> passing through 3 pnt2d <p1>,<p2>,<p3>.

        Parameters
        ----------
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        P3: gp_Pnt2d

        Returns
        -------
        None
        Make a circ from geom2d <thecirc> by its center an radius.

        Parameters
        ----------
        P: gp_Pnt2d
        Radius: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Makes a circle from geom2d <thecirc> with its center <center> and a point giving the radius. if sense is true the local coordinate system of the solution is direct and non direct in the other case. warning the makecircle class does not prevent the construction of a circle with a null radius. if an error occurs (that is, when isdone returns false), the status function returns: - gce_negativeradius if radius is less than 0.0, or - gce_intersectionerror if points p1, p2 and p3 are collinear and the three are not coincident.

        Parameters
        ----------
        Center: gp_Pnt2d
        Point: gp_Pnt2d
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeCircle_swiginit(self, _GCE2d.new_GCE2d_MakeCircle(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Circle > const &":
        r"""
        Returns the constructed circle. exceptions stdfail_notdone if no circle is constructed.

        Returns
        -------
        opencascade::handle<Geom2d_Circle>

        """
        return _GCE2d.GCE2d_MakeCircle_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeCircle

# Register GCE2d_MakeCircle in _GCE2d:
_GCE2d.GCE2d_MakeCircle_swigregister(GCE2d_MakeCircle)

class GCE2d_MakeEllipse(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an ellipse from a non persistent one from package gp.

        Parameters
        ----------
        E: gp_Elips2d

        Returns
        -------
        None
        Majoraxis is the local coordinate system of the ellipse. it is the 'xaxis'. the minor axis is the yaxis of the ellipse. sense give the sense of parametrization of the ellipse. it is not forbidden to create an ellipse with majorradius = minorradius. the status is 'invertradius' if majorradius < minorradius or 'negativeradius' if minorradius < 0.

        Parameters
        ----------
        MajorAxis: gp_Ax2d
        MajorRadius: float
        MinorRadius: float
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Axis is the local coordinate system of the ellipse. it is not forbidden to create an ellipse with majorradius = minorradius. the status is 'invertradius' if majorradius < minorradius or 'negativeradius' if minorradius < 0.

        Parameters
        ----------
        Axis: gp_Ax22d
        MajorRadius: float
        MinorRadius: float

        Returns
        -------
        None
        Make an ellipse centered on the point center, where - the major axis of the ellipse is defined by center and s1, - its major radius is the distance between center and s1, and - its minor radius is the distance between s2 and the major axis. the implicit orientation of the ellipse is: - the sense defined by axis or e, - the sense defined by points center, s1 and s2, - the trigonometric sense if sense is not given or is true, or - the opposite sense if sense is false.

        Parameters
        ----------
        S1: gp_Pnt2d
        S2: gp_Pnt2d
        Center: gp_Pnt2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeEllipse_swiginit(self, _GCE2d.new_GCE2d_MakeEllipse(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Ellipse > const &":
        r"""
        Returns the constructed ellipse. exceptions stdfail_notdone if no ellipse is constructed.

        Returns
        -------
        opencascade::handle<Geom2d_Ellipse>

        """
        return _GCE2d.GCE2d_MakeEllipse_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeEllipse

# Register GCE2d_MakeEllipse in _GCE2d:
_GCE2d.GCE2d_MakeEllipse_swigregister(GCE2d_MakeEllipse)

class GCE2d_MakeHyperbola(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an hyperbola from a non persistent one from package gp.

        Parameters
        ----------
        H: gp_Hypr2d

        Returns
        -------
        None
        Majoraxis is the 'xaxis' of the hyperbola. the major radius of the hyperbola is on this 'xaxis' and the minor radius is on the 'yaxis' of the hyperbola. the status is 'negativeradius' if majorradius < 0.0 or if minorradius < 0.0.

        Parameters
        ----------
        MajorAxis: gp_Ax2d
        MajorRadius: float
        MinorRadius: float
        Sense: bool

        Returns
        -------
        None
        Axis is the local coordinate system of the hyperbola. the major radius of the hyperbola is on this 'xaxis' and the minor radius is on the 'yaxis' of the hyperbola. the status is 'negativeradius' if majorradius < 0.0 or if minorradius < 0.0.

        Parameters
        ----------
        Axis: gp_Ax22d
        MajorRadius: float
        MinorRadius: float

        Returns
        -------
        None
        Creates a hyperbol centered on the origin of the coordinate system axis, with major and minor radii majorradius and minorradius, where the major axis is the 'x axis' of axis (axis is the local coordinate system of the hyperbola). the implicit orientation of the ellipse is: - the sense defined by axis or h, - the sense defined by points center, s1 and s2, - the trigonometric sense if sense is not given or is true, or - the opposite sense if sense is false. warning if an error occurs (that is, when isdone returns false), the status function returns: - gce_negativeradius if majorradius or minorradius is less than 0.0, or - gce_invertaxis if the major radius defined by center and s1 is less than the minor radius defined by center, s1 and s2.make an hyperbola with its center and two apexes.

        Parameters
        ----------
        S1: gp_Pnt2d
        S2: gp_Pnt2d
        Center: gp_Pnt2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeHyperbola_swiginit(self, _GCE2d.new_GCE2d_MakeHyperbola(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Hyperbola > const &":
        r"""
        Returns the constructed hyperbola. exceptions: stdfail_notdone if no hyperbola is constructed.

        Returns
        -------
        opencascade::handle<Geom2d_Hyperbola>

        """
        return _GCE2d.GCE2d_MakeHyperbola_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeHyperbola

# Register GCE2d_MakeHyperbola in _GCE2d:
_GCE2d.GCE2d_MakeHyperbola_swigregister(GCE2d_MakeHyperbola)

class GCE2d_MakeLine(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a line located in 2d space with the axis placement a. the location of a is the origin of the line.

        Parameters
        ----------
        A: gp_Ax2d

        Returns
        -------
        None
        Creates a line from a non persistent line from package gp.

        Parameters
        ----------
        L: gp_Lin2d

        Returns
        -------
        None
        P is the origin and v is the direction of the line.

        Parameters
        ----------
        P: gp_Pnt2d
        V: gp_Dir2d

        Returns
        -------
        None
        Make a line from geom2d <thelin> parallel to another lin <lin> and passing through a pnt <point>.

        Parameters
        ----------
        Lin: gp_Lin2d
        Point: gp_Pnt2d

        Returns
        -------
        None
        Make a line from geom2d <thelin> parallel to another lin <lin> at a distance <dist>.

        Parameters
        ----------
        Lin: gp_Lin2d
        Dist: float

        Returns
        -------
        None
        Make a line from geom2d <thelin> passing through 2 pnt <p1>,<p2>. it returns false if <p1> and <p2> are confused. warning if points p1 and p2 coincident (that is, when isdone returns false), the status function returns gce_confusedpoints.

        Parameters
        ----------
        P1: gp_Pnt2d
        P2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeLine_swiginit(self, _GCE2d.new_GCE2d_MakeLine(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Line > const &":
        r"""
        Returns the constructed line. exceptions stdfail_notdone if no line is constructed.

        Returns
        -------
        opencascade::handle<Geom2d_Line>

        """
        return _GCE2d.GCE2d_MakeLine_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeLine

# Register GCE2d_MakeLine in _GCE2d:
_GCE2d.GCE2d_MakeLine_swigregister(GCE2d_MakeLine)

class GCE2d_MakeParabola(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a parabola from a non persistent one.

        Parameters
        ----------
        Prb: gp_Parab2d

        Returns
        -------
        None
        Creates a parabola with its local coordinate system and it's focal length 'focal'. the 'location' point of 'axis' is the vertex of the parabola status is 'negativefocuslength' if focal < 0.0.

        Parameters
        ----------
        Axis: gp_Ax22d
        Focal: float

        Returns
        -------
        None
        Creates a parabola with its 'mirroraxis' and it's focal length 'focal'. mirroraxis is the axis of symmetry of the curve, it is the 'xaxis'. the 'yaxis' is parallel to the directrix of the parabola. the 'location' point of 'mirroraxis' is the vertex of the parabola status is 'negativefocuslength' if focal < 0.0.

        Parameters
        ----------
        MirrorAxis: gp_Ax2d
        Focal: float
        Sense: bool

        Returns
        -------
        None
        D is the directrix of the parabola and f the focus point. the symmetry axis 'xaxis' of the parabola is normal to the directrix and pass through the focus point f, but its 'location' point is the vertex of the parabola. the 'yaxis' of the parabola is parallel to d and its 'location' point is the vertex of the parabola.

        Parameters
        ----------
        D: gp_Ax2d
        F: gp_Pnt2d
        Sense: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Make a parabola with focal point s1 and center o the branch of the parabola returned will have <s1> as focal point the implicit orientation of the parabola is: - the same one as the parabola prb, - the sense defined by the coordinate system axis or the directrix d, - the trigonometric sense if sense is not given or is true, or - the opposite sense if sense is false. warning the makeparabola class does not prevent the construction of a parabola with a null focal distance. if an error occurs (that is, when isdone returns false), the status function returns: - gce_nullfocuslength if focal is less than 0.0, or - gce_nullaxis if points s1 and o are coincident.

        Parameters
        ----------
        S1: gp_Pnt2d
        O: gp_Pnt2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeParabola_swiginit(self, _GCE2d.new_GCE2d_MakeParabola(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_Parabola > const &":
        r"""
        Returns the constructed parabola. exceptions stdfail_notdone if no parabola is constructed.

        Returns
        -------
        opencascade::handle<Geom2d_Parabola>

        """
        return _GCE2d.GCE2d_MakeParabola_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeParabola

# Register GCE2d_MakeParabola in _GCE2d:
_GCE2d.GCE2d_MakeParabola_swigregister(GCE2d_MakeParabola)

class GCE2d_MakeSegment(GCE2d_Root):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Make a segment of line from the 2 points <p1> and <p2>. status is 'confusedpoints' if <p1> and <p2> are confused.

        Parameters
        ----------
        P1: gp_Pnt2d
        P2: gp_Pnt2d

        Returns
        -------
        None
        Make a segment of line from the point <p1> with the direction <p> and ended by the projection of <p2> on the line <p1,v>. status is 'confusedpoints' if <p1> and <p2> are confused.

        Parameters
        ----------
        P1: gp_Pnt2d
        V: gp_Dir2d
        P2: gp_Pnt2d

        Returns
        -------
        None
        Make a segment of line from the line <line> between the two parameters u1 and u2. status is 'sameparamters' if <u1> is equal <u2>.

        Parameters
        ----------
        Line: gp_Lin2d
        U1: float
        U2: float

        Returns
        -------
        None
        Make a segment of line from the line <line> between the point <point> and the parameter ulast. it returns nullobject if <u1> is equal <u2>.

        Parameters
        ----------
        Line: gp_Lin2d
        Point: gp_Pnt2d
        Ulast: float

        Returns
        -------
        None
        Make a segment of line from the line <line> between the two points <p1> and <p2>. it returns nullobject if <p1> and <p2> are confused. warning if the points which limit the segment are coincident for given points or for the projection of given points on the line which supports the line segment (that is, when isdone returns false), the status function returns gce_confusedpoints. this warning only concerns the first two constructors.

        Parameters
        ----------
        Line: gp_Lin2d
        P1: gp_Pnt2d
        P2: gp_Pnt2d

        Returns
        -------
        None

        """
        _GCE2d.GCE2d_MakeSegment_swiginit(self, _GCE2d.new_GCE2d_MakeSegment(*args))

    def Value(self, *args) -> "opencascade::handle< Geom2d_TrimmedCurve > const &":
        r"""
        Returns the constructed line segment. exceptions stdfail_notdone if no line segment is constructed.

        Returns
        -------
        opencascade::handle<Geom2d_TrimmedCurve>

        """
        return _GCE2d.GCE2d_MakeSegment_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCE2d.delete_GCE2d_MakeSegment

# Register GCE2d_MakeSegment in _GCE2d:
_GCE2d.GCE2d_MakeSegment_swigregister(GCE2d_MakeSegment)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMFunction module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmfunction.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMFunction
else:
    import _XmlMFunction

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMFunction.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMFunction.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMFunction.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMFunction.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMFunction.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMFunction.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMFunction.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMFunction.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMFunction.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMFunction.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMFunction:
_XmlMFunction.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMFunction.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMFunction_FunctionDriver_Create() -> "opencascade::handle< XmlMFunction_FunctionDriver >":
    return _XmlMFunction.Handle_XmlMFunction_FunctionDriver_Create()

def Handle_XmlMFunction_FunctionDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMFunction_FunctionDriver >":
    return _XmlMFunction.Handle_XmlMFunction_FunctionDriver_DownCast(t)

def Handle_XmlMFunction_FunctionDriver_IsNull(t: "opencascade::handle< XmlMFunction_FunctionDriver > const &") -> "bool":
    return _XmlMFunction.Handle_XmlMFunction_FunctionDriver_IsNull(t)

def Handle_XmlMFunction_GraphNodeDriver_Create() -> "opencascade::handle< XmlMFunction_GraphNodeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_GraphNodeDriver_Create()

def Handle_XmlMFunction_GraphNodeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMFunction_GraphNodeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_GraphNodeDriver_DownCast(t)

def Handle_XmlMFunction_GraphNodeDriver_IsNull(t: "opencascade::handle< XmlMFunction_GraphNodeDriver > const &") -> "bool":
    return _XmlMFunction.Handle_XmlMFunction_GraphNodeDriver_IsNull(t)

def Handle_XmlMFunction_ScopeDriver_Create() -> "opencascade::handle< XmlMFunction_ScopeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_ScopeDriver_Create()

def Handle_XmlMFunction_ScopeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMFunction_ScopeDriver >":
    return _XmlMFunction.Handle_XmlMFunction_ScopeDriver_DownCast(t)

def Handle_XmlMFunction_ScopeDriver_IsNull(t: "opencascade::handle< XmlMFunction_ScopeDriver > const &") -> "bool":
    return _XmlMFunction.Handle_XmlMFunction_ScopeDriver_IsNull(t)
class xmlmfunction(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute storage drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMFunction.xmlmfunction_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMFunction.xmlmfunction_swiginit(self, _XmlMFunction.new_xmlmfunction())
    __swig_destroy__ = _XmlMFunction.delete_xmlmfunction

# Register xmlmfunction in _XmlMFunction:
_XmlMFunction.xmlmfunction_swigregister(xmlmfunction)

def xmlmfunction_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute storage drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    theMessageDriver: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMFunction.xmlmfunction_AddDrivers(*args)

class XmlMFunction_FunctionDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMFunction.XmlMFunction_FunctionDriver_swiginit(self, _XmlMFunction.new_XmlMFunction_FunctionDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMFunction.XmlMFunction_FunctionDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMFunction_FunctionDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMFunction.delete_XmlMFunction_FunctionDriver

# Register XmlMFunction_FunctionDriver in _XmlMFunction:
_XmlMFunction.XmlMFunction_FunctionDriver_swigregister(XmlMFunction_FunctionDriver)

class XmlMFunction_GraphNodeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMFunction.XmlMFunction_GraphNodeDriver_swiginit(self, _XmlMFunction.new_XmlMFunction_GraphNodeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMFunction.XmlMFunction_GraphNodeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMFunction_GraphNodeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMFunction.delete_XmlMFunction_GraphNodeDriver

# Register XmlMFunction_GraphNodeDriver in _XmlMFunction:
_XmlMFunction.XmlMFunction_GraphNodeDriver_swigregister(XmlMFunction_GraphNodeDriver)

class XmlMFunction_ScopeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMFunction.XmlMFunction_ScopeDriver_swiginit(self, _XmlMFunction.new_XmlMFunction_ScopeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMFunction.XmlMFunction_ScopeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMFunction_ScopeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMFunction.delete_XmlMFunction_ScopeDriver

# Register XmlMFunction_ScopeDriver in _XmlMFunction:
_XmlMFunction.XmlMFunction_ScopeDriver_swigregister(XmlMFunction_ScopeDriver)





